def argv(name: int) -> str:
    """
    获取Icarus命令行参数
    :param name: 可以是整型也可以是字符串
    :return: 值
    """
    ...


def env(name: str, value: str) -> str:
    """
    获取Icarus环境变量
    :param name: 变量名
    :param value: 若此参数不存在则为获取，若此参数存在则为修改
    :return: 环境变量的值
    """
    ...


def shell_exec(cmd: str, args: list, cmd_dir: str) -> None:
    """
    在本地执行shell命令，以任务执行，非阻塞函数。
    :param cmd: 要执行的命令
    :param args: 命令行参数，类型为字符串列表，可省略
    :param cmd_dir: 执行命令的位置，可省略
    :return: 返回任务id
    """



def echo(something, color: int, end: str) -> None:
    """
    建议使用的输出\n
    :param something: 可以为任意类型，如果是字典，列表将输出他们在go中的结构
    :param color: 输出的颜色，可省略，默认为白色
    :param end: 输出的结尾，可省略，默认为换行符
    :return:
    """
    ...


def select(title: str, items: list) -> (int, str):
    """
    生成一个选择菜单，方向键选择，Enter确认 \n
    :param title: 标题
    :param items: 可选择的项目，字符串列表，若为空则不会阻塞
    :return: 返回选项序号与选项文本
    """
    ...


def match(left: str, right: str, text: str) -> list:
    """
    匹配文本中满足条件的全部文本（正则实现）\n
    e.g.
    \t echo(match("a", "c", "abc aqc")) \n
    \t result: ["b","q"] \n
    :param left: 左侧文本
    :param right: 右侧文本
    :param text: 需要匹配的文本
    :return: 返回包含结果的字符串列表
    """
    ...



import setuptools

try:
    with open('README.md', encoding="utf-8") as f:
        long_description = f.read()
except Exception as e:
    long_description = "Long Description Load Failed"
    print(str(e))
    exit(0)
setuptools.setup(
    name="IcarusApi",
    version="0.0.1",
    author="N0P3",
    author_email="n0p3@qq.com",
    description="Icarus Api",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),
    py_modules=[]
)